countries = {
    "kabul": "afghanistan",
    "tirana": "albania",
    "alger": "algeria",
    "fagatogo": "american samoa",
    "andorra la vella": "andorra",
    "luanda": "angola",
    "the valley": "anguilla",
    "null": "united states minor outlying islands",
    "saint john's": "antigua and barbuda",
    "buenos aires": "argentina",
    "yerevan": "armenia",
    "oranjestad": "aruba",
    "canberra": "australia",
    "wien": "austria",
    "baku": "azerbaijan",
    "nassau": "bahamas",
    "al-manama": "bahrain",
    "dhaka": "bangladesh",
    "bridgetown": "barbados",
    "minsk": "belarus",
    "bruxelles [brussel]": "belgium",
    "belmopan": "belize",
    "porto-novo": "benin",
    "hamilton": "bermuda",
    "thimphu": "bhutan",
    "la paz": "bolivia",
    "sarajevo": "bosnia and herzegovina",
    "gaborone": "botswana",
    "brasília": "brazil",
    "bandar seri begawan": "brunei",
    "sofia": "bulgaria",
    "ouagadougou": "burkina faso",
    "bujumbura": "burundi",
    "phnom penh": "cambodia",
    "yaound": "cameroon",
    "ottawa": "canada",
    "praia": "cape verde",
    "george town": "cayman islands",
    "bangui": "central african republic",
    "n'djam": "chad",
    "santiago de chile": "chile",
    "peking": "china",
    "flying fish cove": "christmas island",
    "west island": "cocos (keeling) islands",
    "santaf": "colombia",
    "moroni": "comoros",
    "brazzaville": "congo",
    "avarua": "cook islands",
    "san jos": "costa rica",
    "zagreb": "croatia",
    "la habana": "cuba",
    "nicosia": "cyprus",
    "praha": "czech republic",
    "copenhagen": "denmark",
    "djibouti": "djibouti",
    "roseau": "dominica",
    "santo domingo de guzm": "dominican republic",
    "dili": "east timor",
    "quito": "ecuador",
    "cairo": "egypt",
    "san salvador": "el salvador",
    "london": "united kingdom",
    "malabo": "equatorial guinea",
    "asmara": "eritrea",
    "tallinn": "estonia",
    "addis abeba": "ethiopia",
    "stanley": "falkland islands",
    "tórshavn": "faroe islands",
    "suva": "fiji islands",
    "helsinki [helsingfors]": "finland",
    "paris": "france",
    "cayenne": "french guiana",
    "papeete": "french polynesia",
    "libreville": "gabon",
    "banjul": "gambia",
    "tbilisi": "georgia",
    "berlin": "germany",
    "accra": "ghana",
    "gibraltar": "gibraltar",
    "athenai": "greece",
    "nuuk": "greenland",
    "saint george's": "grenada",
    "basse-terre": "guadeloupe",
    "aga": "guam",
    "ciudad de guatemala": "guatemala",
    "conakry": "guinea",
    "bissau": "guinea-bissau",
    "georgetown": "guyana",
    "port-au-prince": "haiti",
    "citt": "holy see (vatican capital state)",
    "tegucigalpa": "honduras",
    "victoria": "seychelles",
    "budapest": "hungary",
    "reykjav": "iceland",
    "new delhi": "india",
    "jakarta": "indonesia",
    "tehran": "iran",
    "baghdad": "iraq",
    "dublin": "ireland",
    "jerusalem": "israel",
    "roma": "italy",
    "yamoussoukro": "ivory coast",
    "kingston": "norfolk island",
    "tokyo": "japan",
    "amman": "jordan",
    "astana": "kazakhstan",
    "nairobi": "kenya",
    "bairiki": "kiribati",
    "kuwait": "kuwait",
    "bishkek": "kyrgyzstan",
    "vientiane": "laos",
    "riga": "latvia",
    "beirut": "lebanon",
    "maseru": "lesotho",
    "monrovia": "liberia",
    "tripoli": "libyan arab jamahiriya",
    "vaduz": "liechtenstein",
    "vilnius": "lithuania",
    "luxembourg [luxemburg/l": "luxembourg",
    "macao": "macao",
    "skopje": "north macedonia",
    "antananarivo": "madagascar",
    "lilongwe": "malawi",
    "kuala lumpur": "malaysia",
    "male": "maldives",
    "bamako": "mali",
    "valletta": "malta",
    "dalap-uliga-darrit": "marshall islands",
    "fort-de-france": "martinique",
    "nouakchott": "mauritania",
    "port-louis": "mauritius",
    "mamoutzou": "mayotte",
    "ciudad de m": "mexico",
    "palikir": "micronesia, federated states of",
    "chisinau": "moldova",
    "monaco-ville": "monaco",
    "ulan bator": "mongolia",
    "plymouth": "montserrat",
    "rabat": "morocco",
    "maputo": "mozambique",
    "rangoon (yangon)": "myanmar",
    "windhoek": "namibia",
    "yaren": "nauru",
    "kathmandu": "nepal",
    "amsterdam": "netherlands",
    "willemstad": "netherlands antilles",
    "noum": "new caledonia",
    "wellington": "new zealand",
    "managua": "nicaragua",
    "niamey": "niger",
    "abuja": "nigeria",
    "alofi": "niue",
    "pyongyang": "north korea",
    "belfast": "northern ireland",
    "garapan": "northern mariana islands",
    "oslo": "norway",
    "masqat": "oman",
    "islamabad": "pakistan",
    "koror": "palau",
    "gaza": "palestine",
    "ciudad de panam": "panama",
    "port moresby": "papua new guinea",
    "asunci": "paraguay",
    "lima": "peru",
    "manila": "philippines",
    "adamstown": "pitcairn",
    "warszawa": "poland",
    "lisboa": "portugal",
    "san juan": "puerto rico",
    "doha": "qatar",
    "saint-denis": "reunion",
    "bucuresti": "romania",
    "moscow": "russian federation",
    "kigali": "rwanda",
    "jamestown": "saint helena",
    "basseterre": "saint kitts and nevis",
    "castries": "saint lucia",
    "saint-pierre": "saint pierre and miquelon",
    "kingstown": "saint vincent and the grenadines",
    "apia": "samoa",
    "san marino": "san marino",
    "s": "sao tome and principe",
    "riyadh": "saudi arabia",
    "edinburgh": "scotland",
    "dakar": "senegal",
    "freetown": "sierra leone",
    "singapore": "singapore",
    "bratislava": "slovakia",
    "ljubljana": "slovenia",
    "honiara": "solomon islands",
    "mogadishu": "somalia",
    "pretoria": "south africa",
    "seoul": "south korea",
    "juba": "south sudan",
    "madrid": "spain",
    "khartum": "sudan",
    "paramaribo": "suriname",
    "longyearbyen": "svalbard and jan mayen",
    "mbabane": "swaziland",
    "stockholm": "sweden",
    "bern": "switzerland",
    "damascus": "syria",
    "dushanbe": "tajikistan",
    "dodoma": "tanzania",
    "bangkok": "thailand",
    "lom": "togo",
    "fakaofo": "tokelau",
    "nuku'alofa": "tonga",
    "port-of-spain": "trinidad and tobago",
    "tunis": "tunisia",
    "ankara": "turkey",
    "ashgabat": "turkmenistan",
    "cockburn town": "turks and caicos islands",
    "funafuti": "tuvalu",
    "kampala": "uganda",
    "kyiv": "ukraine",
    "abu dhabi": "united arab emirates",
    "washington": "united states",
    "montevideo": "uruguay",
    "toskent": "uzbekistan",
    "port-vila": "vanuatu",
    "caracas": "venezuela",
    "hanoi": "vietnam",
    "road town": "virgin islands, british",
    "charlotte amalie": "virgin islands, u.s.",
    "cardiff": "wales",
    "mata-utu": "wallis and futuna",
    "el-aai": "western sahara",
    "sanaa": "yemen",
    "beograd": "yugoslavia",
    "lusaka": "zambia",
    "harare": "zimbabwe"
}
